# -*- coding: utf-8 -*-

import threading
from .consts import PLACE_HOLDER
from .skt import env


class ConnCtx(threading.local):
    def __init__(self):
        env.require('gevent_patched')
        super(ConnCtx, self).__init__()
        self.conn_ctx = {}
        self.call_meta_data = {}
        self.logging_meta = {}
        self.user_request_ctx = {}  # user data

    def clear_api_ctx(self):
        self.call_meta_data.clear()
        self.logging_meta.clear()

    def clear_conn_ctx(self):
        self.conn_ctx.clear()

    def clear_user_request_ctx(self):
        self.user_request_ctx.clear()

    def set_call_meta(self, key, value):
        self.call_meta_data[key] = value

    def set_conn_meta(self, key, value):
        self.conn_ctx[key] = value

    def set_user_request_ctx(self, key, value):
        self.user_request_ctx[key] = value

    def get_call_meta(self, key):
        return self.call_meta_data.get(key, PLACE_HOLDER)

    def get_conn_meta(self, key):
        return self.conn_ctx.get(key, PLACE_HOLDER)

    def get_user_request_ctx(self, key):
        return self.user_request_ctx[key]

    def clear_all(self):
        self.clear_api_ctx()
        self.clear_conn_ctx()
        self.clear_user_request_ctx()

g = ConnCtx()



# -*- coding: utf-8 -*-

import sys
import contextlib
import click
from ..consts import DEFAULT_APP_PORT
from ...client import Client

import __main__


@contextlib.contextmanager
def _client_ctx(app_name, service, host, port):
    pass


@click.command()
@click.option('-h', '--host', default='localhost',
              help='service host(default localhost)')
@click.option('-p', '--port', default=DEFAULT_APP_PORT, help='service port')
@click.option('-r', '--rpc', default=False, is_flag=True,
              help='if use rpc connect')
@click.option('--profile', default=False, is_flag=True,
              help='Profile all apis calls')
def shell(host, port, rpc, profile):
    user_ns = __main__.__dict__
    c = Client(host, port)

    def embed_with_cli(client):
        import IPython
        del sys.exitfunc
        user_ns.update(dict(c=client))
        IPython.embed(user_ns=user_ns)
    embed_with_cli(c)



# -*- coding: utf-8 -*-

import requests
import json


##
# http client
##
class Client(object):

    def __init__(self, host, port):
        self.url = "http://{}:{}".format(host, port)

    def get(self, route):
        return requests.get(self.url + route)

    def post(self, route, payload):
        return requests.post(self.url + route, data=json.dumps(payload))



# -*- coding: utf-8 -*-

PLACE_HOLDER = '-'

DEFAULT_TOO_BUSY_ERROR_CODE = -1
DEFAULT_TOO_BUSY_EXC_NAME = 'TOO_BUSY_ERROR'
DEFAULT_TOO_BUSY_MSG = u"SOME THING TOO BUSY"

DEFAULT_BACKOFF_ERROR_CODE = -3
DEFAULT_BACKOFF_EXC_NAME = 'BACKOFF_ERROR'

SHIELDED_API_KEY = 'shielded_apis'
DEFAULT_STATSD = ""
